@@ -16,14 +16,12 @@ from mitosheet.api.get_datafiles import get_datafiles
 from mitosheet.api.get_dateframe_as_csv import get_dataframe_as_csv
 from mitosheet.api.get_dateframe_as_excel import get_dataframe_as_excel
 from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
-from mitosheet.api.get_import_summary import get_import_summary
 from mitosheet.api.get_path_contents import get_path_contents
 from mitosheet.api.get_path_join import get_path_join
 from mitosheet.api.get_pivot_params import get_pivot_params
-from mitosheet.api.get_saved_analysis_description import \
-    get_saved_analysis_description
 from mitosheet.api.get_search_matches import get_search_matches
 from mitosheet.api.get_sheet_data import get_sheet_data
+from mitosheet.api.get_starting_formula import get_starting_formula
 from mitosheet.api.get_unique_value_counts import get_unique_value_counts
 from mitosheet.api.graph import get_graph
 from mitosheet.mito_analytics import log_event_processed
@@ -115,8 +113,6 @@ def handle_api_event(send, event, steps_manager):
         result = get_path_contents(event)
     elif event['type'] == 'get_path_join':
         result = get_path_join(event)
-    elif event['type'] == 'import_summary':
-        result = get_import_summary(event)
     elif event['type'] == 'get_dataframe_as_csv':
         result = get_dataframe_as_csv(event, steps_manager)
     elif event['type'] == 'get_graph':
@@ -125,8 +121,6 @@ def handle_api_event(send, event, steps_manager):
         result = get_column_describe(event, steps_manager)
     elif event['type'] == 'get_column_dtype':
         result = get_column_dtype(event, steps_manager)
-    elif event['type'] == 'get_saved_analysis_description':
-        result = get_saved_analysis_description(event, steps_manager)
     elif event['type'] == 'get_pivot_params':
         result = get_pivot_params(event, steps_manager)
     elif event['type'] == 'get_excel_file_metadata':
@@ -139,6 +133,8 @@ def handle_api_event(send, event, steps_manager):
         result = get_sheet_data(event, steps_manager)
     elif event['type'] == 'get_dataframe_as_excel':
         result = get_dataframe_as_excel(event, steps_manager)
+    elif event['type'] == 'get_starting_formula':
+        result = get_starting_formula(event, steps_manager)
     else:
         raise Exception(f'Event: {event} is not a valid API call')
     
