@@ -6,6 +6,7 @@ import plotly.graph_objects as go
 from mitosheet.mito_analytics import log
 from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.api.graph.graph_utils import BAR, CREATE_FIG_CODE, SCATTER, SHOW_FIG_CODE, X, Y, filter_df_to_safe_size, get_graph_labels, get_graph_title
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
 
 def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
@@ -45,7 +46,7 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
             fig.add_trace(go.Scatter(
                 y=df[column_header], 
                 mode='markers',
-                name=(' ').join([column_header, filter_label])
+                name=(' ').join([str(column_header), filter_label])
             ))
     elif not x_axis and y_axis:
         # Only a y axis was provided
@@ -53,7 +54,7 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
             fig.add_trace(go.Scatter(
                 x=df[column_header],
                 mode='markers',
-                name=(' ').join([column_header, filter_label])
+                name=(' ').join([str(column_header), filter_label])
             ))
     elif len(y_axis_column_headers) == 1:
         # If the y axis only has one column header, then we use that as the key
@@ -62,7 +63,7 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
                 x=df[column_header], 
                 y=df[y_axis_column_headers[0]],
                 mode='markers',
-                name=(' ').join([column_header, filter_label])
+                name=(' ').join([str(column_header), filter_label])
             ))
     else:
         # It should not be possible for both the x axis and y axis 
@@ -73,7 +74,7 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
                 x=df[x_axis_column_headers[0]], 
                 y=df[column_header],
                 mode='markers',
-                name=(' ').join([column_header, filter_label])
+                name=(' ').join([str(column_header), filter_label])
             ))
 
     # Update the layout of the graph
@@ -121,8 +122,6 @@ from mitosheet import filter_df_to_safe_size
 )
         df_name = f'{df_name}_filtered'
 
-
-
     x_axis = len(x_axis_column_headers) != 0
     y_axis = len(y_axis_column_headers) != 0      
 
@@ -134,7 +133,7 @@ for column_header in {x_axis_column_headers}:
     fig.add_trace(go.Scatter(
         y={df_name}[column_header], 
         mode='markers',
-        name=column_header
+        name=str(column_header)
     ))
 """.format(
     df_name=df_name, 
@@ -148,41 +147,43 @@ for column_header in {y_axis_column_headers}:
     fig.add_trace(go.Scatter(
         x={df_name}[column_header], 
         mode='markers',
-        name=column_header
+        name=str(column_header)
     ))
 """.format(
     df_name=df_name, 
     y_axis_column_headers=y_axis_column_headers
 )
     elif len(y_axis_column_headers) == 1:
+        transpiled_y_axis_column_header = column_header_to_transpiled_code(y_axis_column_headers[0])
         trace_code = """
 # Add the scatter traces to the figure
 for column_header in {x_axis_column_headers}:
     fig.add_trace(go.Scatter(
         x={df_name}[column_header],
-        y={df_name}['{y_axis_column_header}'],
+        y={df_name}[{transpiled_y_axis_column_header}],
         mode='markers',
-        name=column_header
+        name=str(column_header)
     ))
 """.format(
     df_name=df_name, 
     x_axis_column_headers=x_axis_column_headers,
-    y_axis_column_header=y_axis_column_headers[0]
+    transpiled_y_axis_column_header=transpiled_y_axis_column_header
 )
     else:
+        transpiled_x_axis_column_header = column_header_to_transpiled_code(x_axis_column_headers[0])
         trace_code = """
 # Add the scatter traces to the figure
 for column_header in {y_axis_column_headers}:
     fig.add_trace(go.Scatter(
-        x={df_name}['{x_axis_column_header}'],
+        x={df_name}['{transpiled_x_axis_column_header}'],
         y={df_name}[column_header],
         mode='markers',
-        name=column_header
+        name=str(column_header)
     ))
 """.format(
     df_name=df_name, 
     y_axis_column_headers=y_axis_column_headers,
-    x_axis_column_header=x_axis_column_headers[0]
+    transpiled_x_axis_column_header=transpiled_x_axis_column_header
 )
 
     x_axis_title, y_axis_title = get_graph_labels(x_axis_column_headers, y_axis_column_headers)
@@ -195,9 +196,9 @@ for column_header in {y_axis_column_headers}:
 # Update the layout
 # See Plotly documentation for cutomizations: https://plotly.com/python/reference/scatter/
 fig.update_layout(
-    xaxis_title='{x_axis_title}',
-    yaxis_title='{y_axis_title}',
-    title='{graph_title}',
+    xaxis_title="{x_axis_title}",
+    yaxis_title="{y_axis_title}",
+    title="{graph_title}",
 )
 {SHOW_FIG_CODE}""".format(
     CREATE_FIG_CODE=CREATE_FIG_CODE,
