@@ -11,6 +11,7 @@ Notably, the ID of the column header is just a string representation
 of the column header. For string column headers, they are just
 themselves.
 """
+import random
 from typing import Any, Dict, List
 
 import pandas as pd
@@ -37,13 +38,30 @@ def flatten_column_header(column_header: Any):
 
     return column_header
 
+def get_column_header_display(column_header: Any) -> str:
+    """
+    Turns the column header into a string that is the same as how
+    the string is displayed on the front-end. 
+
+    This is useful for, say, the parser, where it gets data from
+    the front-end - where the users enters column headers as they 
+    see them.
+
+    NOTE: must match the equivalent function in src/utils/columnHeaders.tsx
+    """
+    if isinstance(column_header, bool):
+        return 'true' if column_header else 'false'
+    elif isinstance(column_header, tuple):
+        return ', '.join([get_column_header_display(c) for c in column_header if c != ''])
+
+    return str(column_header)
+
 
 def get_column_header_ids(column_headers: List[Any]):
     return [
         get_column_header_id(column_header) for column_header in column_headers
     ]
 
-
 def get_column_header_id(column_header: Any, use_deprecated_id_algorithm=False) -> str:
     """
     Returns the ID that represents this column header, which is
@@ -66,6 +84,26 @@ def get_column_header_id(column_header: Any, use_deprecated_id_algorithm=False)
         return column_header
     else:
         return str(column_header)
+
+def try_make_new_header_valid_if_multi_index_headers(column_headers: List[Any], new_column_header: Any):
+    """
+    Helper function for when you're adding a column to a
+    dataframe that has multi-index headers. 
+
+    In this case, you need to add a new header in a tuple
+    that is the length of the multi-index headers, so
+    this function helps you make such a header
+    """
+    if not isinstance(new_column_header, tuple) and len(column_headers) > 0:
+        other_column_header = random.choice(list(column_headers))
+        if isinstance(other_column_header, tuple):
+            ending_list = ['' for _ in range(len(other_column_header) - 1)]
+            ending_list.insert(0, new_column_header)
+            return tuple(ending_list)
+
+    # If we don't need to change the column header, don't change it
+    return new_column_header
+
     
 
 class ColumnIDMap():
@@ -85,7 +123,23 @@ class ColumnIDMap():
                 self.column_id_to_column_header[sheet_index][column_id] = column_header
                 self.column_header_to_column_id[sheet_index][column_header] = column_id
 
-    def set_column_header(self, sheet_index: int, column_id: str, column_header):
+    def set_column_header(self, sheet_index: int, column_id: str, column_header: Any):
+        """
+        Sets a column id and column header to match to eachother. 
+
+        Takes special care in the case that the existing dataframe is a multi-index
+        headers, in which case even if the new column header is just a string, the
+        the column header that ends up getting created in the dataframe will be a 
+        tuple.
+        
+        """
+        # Make sure the new column header we're setting is in fact valid for this dataframe
+        # header format - as it may be a multi-index header
+        column_header = try_make_new_header_valid_if_multi_index_headers(
+            list(self.column_id_to_column_header[sheet_index].values()),
+            column_header
+        )
+
         old_column_header = self.column_id_to_column_header[sheet_index][column_id]
         del self.column_header_to_column_id[sheet_index][old_column_header]
         
@@ -130,6 +184,13 @@ class ColumnIDMap():
         and not when renaming a column, as it creates a new id for the column
         header!
         """
+        # Make sure the new column header we're setting is in fact valid for this dataframe
+        # header format - as it may be a multi-index header
+        column_header = try_make_new_header_valid_if_multi_index_headers(
+            list(self.column_id_to_column_header[sheet_index].values()),
+            column_header
+        )
+
         column_id = get_column_header_id(column_header)
         self.column_id_to_column_header[sheet_index][column_id] = column_header
         self.column_header_to_column_id[sheet_index][column_header] = column_id
