@@ -100,7 +100,7 @@ def anonymize_formula(formula, sheet_index, steps_manager=None):
     )
     
     for dependency in dependencies:
-        formula = formula.replace(dependency, anonymize_word(dependency))
+        formula = formula.replace(str(dependency), anonymize_word(dependency))
     
     return formula
 
@@ -167,8 +167,6 @@ def log(log_event, params=None, steps_manager=None):
     with a private secret that only the user has, making it impossible
     for us to brute force it.
     """
-    if not telemetry_turned_on():
-        return
 
     if params is None:
         params = {}
@@ -193,7 +191,7 @@ def log(log_event, params=None, steps_manager=None):
     try:
         for key, value in params.items():
             # We take any of the items that contain private user data, and we anonymize them
-            if 'rows' in key or 'columns' in key or 'selected_column_ids' in key:
+            if ('rows' in key and 'skiprows' not in key) or 'columns' in key or 'selected_column_ids' in key:
                 # We anonymize all of the column headers in any list
                 private_params[key] = [anonymize_word(v) for v in value]
             elif ('column_header' in key \
@@ -251,9 +249,12 @@ def log(log_event, params=None, steps_manager=None):
             private_params['error_traceback_last_line'] = recent_traceback[-1] 
         except:
             pass
+    
 
-    # NOTE: we do not log anything when tests are running
-    if not is_running_test():
+    # NOTE: we do not log anything when tests are running, or if telemetry
+    # is turned off. NOTE: we do this check at the end to catch bugs that 
+    # might exist in the above logging code
+    if not is_running_test() and telemetry_turned_on():
         analytics.track(
             get_user_field(UJ_STATIC_USER_ID), 
             log_event, 
