@@ -7,14 +7,13 @@
 Main file containing the mito widget.
 """
 import json
-from mitosheet import step_performers
 from mitosheet.saved_analyses.save_utils import read_saved_analysis_names
 from mitosheet.step_performers import STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID
-from mitosheet.user.schemas import UJ_FEEDBACKS, UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
+from mitosheet.user.schemas import UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
 from mitosheet.user.db import get_user_field
-from mitosheet.utils import get_new_id
+from mitosheet.user.utils import is_pro
 from mitosheet.api import API
-from mitosheet.mito_analytics import log, log_event_processed, log_recent_error
+from mitosheet.mito_analytics import log, log_event_processed, log_recent_error, telemetry_turned_on
 import pandas as pd
 import random
 
@@ -73,6 +72,7 @@ class MitoWidget(DOMWidget):
         # have to recompute them on each update
         self.num_usages = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
         self.usage_triggered_feedback_id = ''
+        self.is_pro = is_pro()
         self.is_local_deployment = is_local_deployment()
         self.should_upgrade_mitosheet = should_upgrade_mitosheet()
         self.received_tours = get_user_field(UJ_RECEIVED_TOURS)
@@ -98,6 +98,7 @@ class MitoWidget(DOMWidget):
             'receivedTours': get_user_field(UJ_RECEIVED_TOURS),
             'savedAnalysisNames': read_saved_analysis_names(),
             # Static over a single analysis
+            'isPro': self.is_pro,
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
             'numUsages': self.num_usages,
@@ -246,8 +247,13 @@ class MitoWidget(DOMWidget):
         Current Feedback Strategy:
         - If the current step type is not the same as the previous step type, then there is a .25% chance that we ask the user for feedback
         """
+        # Don't set the feedback if we're on the first step, or if we're not logging
+        if self.steps_manager.curr_step_idx <= 1 or not telemetry_turned_on():
+            return
+
         # If the current step type is not the same as the previous step type, then there is a .25% chance that we ask the user for feedback
-        previous_step_type = self.steps_manager.steps[self.steps_manager.curr_step_idx - 1].step_type if self.steps_manager.curr_step_idx > 1 else None
+        previous_step_type = self.steps_manager.steps[self.steps_manager.curr_step_idx - 1].step_type
+        
         if self.steps_manager.curr_step.step_type != previous_step_type and previous_step_type != 'bulk_old_rename':
             if random.randint(1, 400) == 1:
                 self.usage_triggered_feedback_id = STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID[previous_step_type]
