@@ -60,51 +60,6 @@ def FILLNAN(series: pd.Series, replacement: pd.Series) -> pd.Series:
 
     return series.fillna(replacement)
 
-@handle_sheet_function_errors
-@filter_nans
-@convert_arg_to_series_type(
-    0,
-    'series',
-    'error',
-    'error'
-)
-#TODO: Fix up the offset for this function, as it should be forced into a number.
-def OFFSET(series: pd.Series, offset) -> pd.Series:
-    """
-    {
-        "function": "OFFSET",
-        "description": "Shifts the given series by the given offset. Use a negative offset to reference a previous row, and a offset number to reference a later row.",
-        "examples": [
-            "OFFSET(Nums, 10)",
-            "OFFSET(call_time, -1)"
-        ],
-        "syntax": "OFFSET(series, offset)",
-        "syntax_elements": [{
-                "element": "series",
-                "description": "The series to shift up or down."
-            },
-            {
-                "element": "offset",
-                "description": "An integer amount to shift. Use a negative number to reference a previous row, and a positive number to reference a later row."
-            }
-        ]
-    }
-    """
-    length = len(series)
-    # If the shift is too big, we just return an empty series
-    if abs(offset) >= length:
-        return pd.Series([np.NaN] * length, index=series.index)
-    
-    if offset < 0:
-        return pd.Series(
-            [np.NaN] * (offset * -1) + series.tolist()
-        ).head(length).reindex(series.index)
-    else:
-        remaining_series = series.tail(length - offset)
-        return pd.Series(
-            remaining_series.tolist() + [np.NaN] * offset,
-        ).head(length).reindex(series.index)
-
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
@@ -163,6 +118,5 @@ def TYPE(series: pd.Series) -> pd.Series:
 # TODO: we should see if we can list these automatically!
 MISC_FUNCTIONS = {
     'FILLNAN': FILLNAN,
-    'OFFSET': OFFSET,
     'TYPE': TYPE
 }
\ No newline at end of file
