@@ -76,11 +76,12 @@ class BulkOldRenameStepPerformer(StepPerformer):
 
             for old_column_header, new_column_header in column_header_renames.items():
                 column_id = post_state.column_ids.get_column_id_by_header(sheet_index, old_column_header)
-                post_state = rename_column_headers_in_state(
+                rename_column_headers_in_state(
                     post_state,
                     sheet_index,
                     column_id,
-                    new_column_header
+                    new_column_header,
+                    None
                 )
 
         if move_to_deprecated_id_algorithm:
