@@ -11,7 +11,7 @@ from mitosheet.step_performers.step_performer import StepPerformer
 from typing import Any, Dict, List, Optional, Tuple
 from mitosheet.state import State
 from mitosheet.sheet_functions.types.utils import get_mito_type
-from mitosheet.topological_sort import creates_circularity, subgraph_from_starting_column_header, topological_sort_columns
+from mitosheet.topological_sort import creates_circularity, subgraph_from_starting_column_id, topological_sort_columns
 from mitosheet.sheet_functions import FUNCTIONS
 from mitosheet.parser import parse_formula
 
@@ -366,7 +366,7 @@ def transpile_dependant_columns(
 
     # We only look at the sheet that was changed, and sort the columns, taking only
     # those downstream from the changed columns
-    subgraph = subgraph_from_starting_column_header(post_state.column_evaluation_graph[sheet_index], column_id)
+    subgraph = subgraph_from_starting_column_id(post_state.column_evaluation_graph[sheet_index], column_id)
     topological_sort = topological_sort_columns(subgraph)
 
     # We compile all of their formulas
