@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -40,13 +40,13 @@ class DataframeDeleteStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
         old_dataframe_name: str,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # Create a new step and save the parameters
         post_state = copy(prev_state)
 
@@ -65,7 +65,7 @@ class DataframeDeleteStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -76,7 +76,7 @@ class DataframeDeleteStepPerformer(StepPerformer):
         return [f'del {old_dataframe_name}']
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         old_dataframe_name: str,
