@@ -10,7 +10,7 @@ from os.path import normpath, basename
 from mitosheet.utils import get_valid_dataframe_names
 import os
 from copy import copy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 import chardet
 import pandas as pd
@@ -47,13 +47,13 @@ class SimpleImportStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         file_names: List[str],
         use_deprecated_id_algorithm: bool=False,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # If any of the files are directories, we throw an error to let
         # the user know
         for file_name in file_names:
@@ -91,7 +91,7 @@ class SimpleImportStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -104,8 +104,8 @@ class SimpleImportStepPerformer(StepPerformer):
         index = 0
         for file_name, df_name in zip(file_names, post_state.df_names[len(post_state.df_names) - len(file_names):]):
 
-            delimeter = execution_data['file_delimeters'][index]
-            encoding = execution_data['file_encodings'][index]
+            delimeter = execution_data['file_delimeters'][index] if execution_data is not None else None
+            encoding = execution_data['file_encodings'][index] if execution_data is not None else None
 
             code.append(
                 generate_read_csv_code(file_name, df_name, delimeter, encoding)
@@ -116,7 +116,7 @@ class SimpleImportStepPerformer(StepPerformer):
         return code
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         file_names: List[str],
         use_deprecated_id_algorithm: bool=False,
