@@ -19,6 +19,7 @@ from mitosheet.state import State
 from mitosheet.step_performers.column_steps.set_column_formula import (
     refresh_dependant_columns, transpile_dependant_columns)
 from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
 
 class SetCellValueStepPerformer(StepPerformer):
@@ -124,18 +125,19 @@ class SetCellValueStepPerformer(StepPerformer):
         type_corrected_new_value = cast_value_to_type(new_value, column_mito_type)
 
         column_header = post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        transpiled_column_header = column_header_to_transpiled_code(column_header)
 
         # If the series is an int, but the new value is a float, convert the series to floats before adding the new value
         column_dtype = str(prev_state.dfs[sheet_index][column_header].dtype)
         if new_value is not None and '.' in new_value and is_int_dtype(column_dtype):
-            code.append(f'{post_state.df_names[sheet_index]}[\'{column_header}\'] = {post_state.df_names[sheet_index]}[\'{column_header}\'].astype(\'float\')')
+            code.append(f'{post_state.df_names[sheet_index]}[{transpiled_column_header}] = {post_state.df_names[sheet_index]}[\'{column_header}\'].astype(\'float\')')
 
         # Actually set the new value
         # We don't need to wrap the value in " if its None, a Boolean Series, or a Number Series.
         if type_corrected_new_value is None or column_mito_type == BOOLEAN_SERIES or column_mito_type == NUMBER_SERIES:
-            code.append(f'{post_state.df_names[sheet_index]}.at[{row_index}, \'{column_header}\'] = {type_corrected_new_value}')
+            code.append(f'{post_state.df_names[sheet_index]}.at[{row_index}, {transpiled_column_header}] = {type_corrected_new_value}')
         else:
-            code.append(f'{post_state.df_names[sheet_index]}.at[{row_index}, \'{column_header}\'] = \"{type_corrected_new_value}\"')
+            code.append(f'{post_state.df_names[sheet_index]}.at[{row_index}, {transpiled_column_header}] = \"{type_corrected_new_value}\"')
 
         # Add the transpiled code for all of the dependant columns inorder to refresh the dependant cells
         code = code + transpile_dependant_columns(post_state, sheet_index, column_id)
