@@ -29,7 +29,8 @@ from mitosheet.step_performers import (
     DataframeDuplicateStepPerformer,
     DataframeRenameStepPerformer,
     BulkOldRenameStepPerformer, 
-    ExcelImportStepPerformer
+    ExcelImportStepPerformer,
+    DropDuplicatesStepPerformer
 )
 
 def check_step(
@@ -91,7 +92,7 @@ def test_params_static():
     
     check_step(
         PivotStepPerformer,
-        5,
+        6,
         'pivot'
     )
 
@@ -168,7 +169,13 @@ def test_params_static():
         'excel_import'
     )
 
-    assert len(STEP_PERFORMERS) == 17
+    check_step(
+        DropDuplicatesStepPerformer,
+        1,
+        'drop_duplicates'
+    )
+
+    assert len(STEP_PERFORMERS) == 18
 
 
 def get_fake_param(param_name):
