@@ -399,6 +399,7 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
     def reorder_column(
             self, 
             sheet_index, 
@@ -588,30 +589,6 @@ class MitoWidgetTestWrapper:
         )
 
 
-    def rename_analysis(self, old_analysis_name, new_analysis_name):
-        return self.mito_widget.receive_message(
-            self.mito_widget,
-            {
-                'event': 'update_event',
-                'id': get_new_id(),
-                'type': 'rename_analysis_update',
-                'old_analysis_name': old_analysis_name,
-                'new_analysis_name': new_analysis_name
-            }
-        )
-
-    
-    def delete_analysis(self, analysis_name):
-        return self.mito_widget.receive_message(
-            self.mito_widget,
-            {
-                'event': 'update_event',
-                'id': get_new_id(),
-                'type': 'delete_analysis_update',
-                'analysis_name': analysis_name
-            }
-        )
-
     @check_transpiled_code_after_call
     def delete_dataframe(self, sheet_index):
         return self.mito_widget.receive_message(
