@@ -64,7 +64,7 @@ def topological_sort_columns(column_evaluation_graph):
     finish_order.reverse()
     return finish_order
 
-def subgraph_from_starting_column_header(column_evaluation_graph, starting_column_header):
+def subgraph_from_starting_column_id(column_evaluation_graph, starting_column_id):
     """
     Filters down the column_evaluation_graph to just the nodes that can be reached
     from the starting_point, including the starting_point itself.
@@ -74,7 +74,7 @@ def subgraph_from_starting_column_header(column_evaluation_graph, starting_colum
     """
     column_evaluation_subgraph = dict()
 
-    nodes_in_subgraph = set([starting_column_header])
+    nodes_in_subgraph = set([starting_column_id])
     while len(nodes_in_subgraph) > 0:
         curr_node = nodes_in_subgraph.pop()
         column_evaluation_subgraph[curr_node] = column_evaluation_graph[curr_node]
