@@ -32,7 +32,7 @@ def column_header_to_transpiled_code(column_header: Any):
 
     if isinstance(column_header, int) or isinstance(column_header, float) or isinstance(column_header, bool):
         return str(column_header)
-    return f'\'{column_header}\''
+    return repr(column_header)
 
 def list_to_string_without_internal_quotes(list) -> str:
     """
