@@ -20,8 +20,6 @@ from mitosheet.updates.clear import CLEAR_UPDATE
 from mitosheet.updates.args_update import ARGS_UPDATE
 from mitosheet.updates.save_analysis import SAVE_ANALYSIS_UPDATE
 from mitosheet.updates.replay_analysis import REPLAY_ANALYSIS_UPDATE
-from mitosheet.updates.delete_saved_analysis import DELETE_SAVED_ANALYSIS_UPDATE
-from mitosheet.updates.rename_saved_analysis import RENAME_SAVED_ANALYSIS_UPDATE
 from mitosheet.updates.set_user_field_update import SET_USER_FIELD_UPDATE
 from mitosheet.updates.checkout_step_by_idx import CHECKOUT_STEP_BY_IDX_UPDATE
 from mitosheet.updates.append_user_field import APPEND_USER_FIELD_UPDATE
@@ -36,8 +34,6 @@ UPDATES = [
     ARGS_UPDATE,
     SAVE_ANALYSIS_UPDATE,
     REPLAY_ANALYSIS_UPDATE,
-    RENAME_SAVED_ANALYSIS_UPDATE,
-    DELETE_SAVED_ANALYSIS_UPDATE,
     CHECKOUT_STEP_BY_IDX_UPDATE,
     APPEND_USER_FIELD_UPDATE,
     SET_USER_FIELD_UPDATE,
