@@ -1,21 +1,18 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-from datetime import datetime
-from typing import Any, Dict
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
 
+from datetime import datetime
 from mitosheet.mito_analytics import identify
-from mitosheet.types import StepsManagerType
 from mitosheet.user import get_user_field, set_user_field
 from mitosheet.user.schemas import UJ_FEEDBACKS_V2
-    
 
 UPDATE_FEEDBACK_V2_OBJECT_EVENT = 'update_feedback_v2_obj_update'
 UPDATE_FEEDBACK_V2_OBJECT_EVENT_PARAMS = ['feedback_id', 'num_usages', 'questions_and_answers']
 
-def execute_add_feedback_update(steps_manager: StepsManagerType, feedback_id: str, num_usages: int, questions_and_answers: Dict[str, Any]) -> None:
+def execute_add_feedback_update(steps_manager, feedback_id, num_usages, questions_and_answers):
     """
     The function responsible for adding the feedback to the feedback_v2 object
     in the user.json. 
@@ -39,7 +36,7 @@ def execute_add_feedback_update(steps_manager: StepsManagerType, feedback_id: st
     # Add the new feedback to the feedback_obj
     user_feedback_obj[feedback_id].append(new_feedback_obj)
     
-    # Set the field to the new list
+    # set the field to the new list
     set_user_field(UJ_FEEDBACKS_V2, user_feedback_obj)
 
     # Identify just in case
@@ -50,4 +47,4 @@ UPDATE_FEEDBACK_V2_OBJECT_UPDATE = {
     'event_type': UPDATE_FEEDBACK_V2_OBJECT_EVENT,
     'params': UPDATE_FEEDBACK_V2_OBJECT_EVENT_PARAMS,
     'execute': execute_add_feedback_update
-}
+}
\ No newline at end of file
