@@ -32,7 +32,7 @@ the other.
 _Any change the user.json format must be met with a version bump._
 """
 from mitosheet.user.schemas import (
-    UJ_FEEDBACKS_V2, UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES, UJ_MITOSHEET_TELEMETRY,
+    UJ_FEEDBACKS_V2, UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_PRO, UJ_MITOSHEET_LAST_FIVE_USAGES, UJ_MITOSHEET_TELEMETRY,
     UJ_USER_JSON_VERSION, UJ_MITOSHEET_LAST_FIFTY_USAGES
 )
 from mitosheet.user.schemas import USER_JSON_DEFAULT, USER_JSON_VERSION_1
@@ -98,13 +98,17 @@ def upgrade_final_user_json_version_1_to_2(final_user_json_version_1):
 
 def upgrade_user_json_version_2_to_3(user_json_version_2):
     """
-    Just adds the user json telemtry field
+    Just adds the user json telemetry field, which may already
+    be set (due to it being added to the installer). Thus, only
+    if it doesn't exist, we set it to True
     """
     # First, bump the version number
     user_json_version_2[UJ_USER_JSON_VERSION] = 3
 
     # Then, set new field
-    user_json_version_2[UJ_MITOSHEET_TELEMETRY] = True
+    if UJ_MITOSHEET_TELEMETRY not in user_json_version_2:
+        user_json_version_2[UJ_MITOSHEET_TELEMETRY] = True
+
     return user_json_version_2
 
 def upgrade_user_json_version_3_to_4(user_json_version_3):
@@ -118,6 +122,20 @@ def upgrade_user_json_version_3_to_4(user_json_version_3):
     user_json_version_3[UJ_FEEDBACKS_V2] = {}
     return user_json_version_3
 
+def upgrade_user_json_version_4_to_5(user_json_version_4):
+    """
+    Just adds the UJ_MITOSHEET_PRO field, and sets it to False,
+    if it is not already in the user json (which it may be,
+    as it is now set by the installer). 
+    """
+    # First, bump the version number
+    user_json_version_4[UJ_USER_JSON_VERSION] = 5
+
+    # Then, set new field
+    if UJ_MITOSHEET_PRO not in user_json_version_4:
+        user_json_version_4[UJ_MITOSHEET_PRO] = False
+    return user_json_version_4
+
 def try_upgrade_user_json_to_current_version():
     user_json_object = get_user_json_object()
 
@@ -136,6 +154,9 @@ def try_upgrade_user_json_to_current_version():
         user_json_object = upgrade_user_json_version_2_to_3(user_json_object)
     if user_json_object[UJ_USER_JSON_VERSION] == 3:
         user_json_object = upgrade_user_json_version_3_to_4(user_json_object)
+    if user_json_object[UJ_USER_JSON_VERSION] == 4:
+        user_json_object = upgrade_user_json_version_4_to_5(user_json_object)
+
 
     set_user_json_object(user_json_object)
 
