@@ -15,7 +15,7 @@ from datetime import datetime
 from mitosheet._version import __version__
 from mitosheet.user.db import get_user_field
 from mitosheet.user.schemas import (
-    UJ_FEEDBACKS, UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES
+    UJ_FEEDBACKS, UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_MITOSHEET_PRO
 )
 
 def is_running_test():
@@ -39,6 +39,14 @@ def is_on_kuberentes_mito():
     return user == 'jovyan'
 
 
+def is_pro():
+    """
+    Helper function for returning if this is a
+    pro deployment of mito
+    """
+    return not get_user_field(UJ_MITOSHEET_PRO)  
+
+
 def is_local_deployment():
     """
     Helper function for figuring out if this a local deployment or a
